input_row

Function input_row 

pub fn input_row(
    label: &str,
    pad: usize,
    value: &str,
    active: bool,
    error: bool,
    caret: Option<usize>,
    theme: &Theme,
) -> Line<'static>
Render a text-input row.

When active is true, the value is wrapped in brackets. If caret is Some(idx), a bold is inserted at character index idx (software caret). When active is false, the value renders plain.