pub struct ListState {
pub selected: usize,
/* private fields */
}Expand description
Scroll and selection state for a render_list widget.
Fields
selected: usizeIndex of the currently selected item.
Implementations
Sourceimpl ListState
impl ListState
Sourcepub fn select_next(&mut self, item_count: usize)
pub fn select_next(&mut self, item_count: usize)
Move selection to the next item, wrapping around at the end.
Sourcepub fn select_prev(&mut self)
pub fn select_prev(&mut self)
Move selection to the previous item, wrapping around at the beginning.