pub struct TreeState {
pub selected: usize,
/* private fields */
}Expand description
Selection + scroll state for a render_tree widget, over the slice of
currently-visible rows.
Fields
selected: usizeIndex of the selected row within the visible rows.
Implementations
Sourceimpl TreeState
impl TreeState
pub fn new() -> Self
Sourcepub fn select_next(&mut self, row_count: usize)
pub fn select_next(&mut self, row_count: usize)
Move selection to the next visible row, wrapping at the end.
Sourcepub fn select_prev(&mut self, row_count: usize)
pub fn select_prev(&mut self, row_count: usize)
Move selection to the previous visible row, wrapping at the start.
pub fn selected(&self) -> usize
pub fn offset(&self) -> usize