pub struct FormState {
pub fields: Vec<FormField>,
pub focused: usize,
/* private fields */
}Expand description
State for the render_form widget.
Fields
fields: Vec<FormField>The form fields.
focused: usizeIndex of the currently focused field.
Implementations
Sourceimpl FormState
impl FormState
Sourcepub fn focus_next(&mut self)
pub fn focus_next(&mut self)
Move focus to the next field, stopping at the last.
Sourcepub fn focus_prev(&mut self)
pub fn focus_prev(&mut self)
Move focus to the previous field, stopping at the first.
Sourcepub fn handle_key(&mut self, key: KeyEvent) -> FormEvent
pub fn handle_key(&mut self, key: KeyEvent) -> FormEvent
Handle a key event, updating internal state and returning a FormEvent.
Sourcepub fn into_fields(self) -> Vec<FormField>
pub fn into_fields(self) -> Vec<FormField>
Consume the state and return the fields with their current input values.